@@ -11,10 +11,19 @@ log = logging.getLogger(__name__)
 
 class TempFile(VFSFile):
     """A temporary file."""
-    __module__ = 'pyobs.vfs'
 
-    def __init__(self, name: Optional[str] = None, mode: str = 'r', prefix: Optional[str] = None,
-                 suffix: Optional[str] = None, root: str = '/tmp/pyobs/', mkdir: bool = True, **kwargs: Any):
+    __module__ = "pyobs.vfs"
+
+    def __init__(
+        self,
+        name: Optional[str] = None,
+        mode: str = "r",
+        prefix: Optional[str] = None,
+        suffix: Optional[str] = None,
+        root: str = "/tmp/pyobs/",
+        mkdir: bool = True,
+        **kwargs: Any,
+    ):
         """Open/create a temp file.
 
         Args:
@@ -28,7 +37,7 @@ class TempFile(VFSFile):
 
         # no root given?
         if root is None:
-            raise ValueError('No root directory given.')
+            raise ValueError("No root directory given.")
 
         # create root?
         if not os.path.exists(root):
@@ -37,16 +46,16 @@ class TempFile(VFSFile):
         # no filename?
         if name is None:
             # cannot read from non-existing filename
-            if 'r' in mode:
-                raise ValueError('No filename given to read from.')
+            if "r" in mode:
+                raise ValueError("No filename given to read from.")
 
             # create new temp file name
             with NamedTemporaryFile(mode=mode, prefix=prefix, suffix=suffix, dir=root) as tmp:
                 name = os.path.basename(tmp.name)
 
         # filename is not allowed to start with a / or contain ..
-        if name.startswith('/') or '..' in name:
-            raise ValueError('Only files within root directory are allowed.')
+        if name.startswith("/") or ".." in name:
+            raise ValueError("Only files within root directory are allowed.")
 
         # build filename
         self.filename = name
@@ -58,7 +67,7 @@ class TempFile(VFSFile):
             if mkdir:
                 os.makedirs(path)
             else:
-                raise ValueError('Cannot write into sub-directory with disabled mkdir option.')
+                raise ValueError("Cannot write into sub-directory with disabled mkdir option.")
 
         # init fd
         self.mode = mode
@@ -72,7 +81,7 @@ class TempFile(VFSFile):
             self.fd.close()
 
         # remove file
-        if 'w' in self.mode:
+        if "w" in self.mode:
             os.remove(self.full_name)
 
     async def read(self, n: int = -1) -> AnyStr:
@@ -86,4 +95,4 @@ class TempFile(VFSFile):
         self.fd.write(s)
 
 
-__all__ = ['TempFile']
+__all__ = ["TempFile"]
